import nltk
nltk.download('stopwords')
from nltk.corpus import stopwords
import re
import numpy as np
import tensorflow as tf
import joblib
import os #to interact with operating system 

class BaseModel():
    """
    BaseModel Class
    """

    def __init__(self):
        curr_dir=os.getcwd()
        model_path=os.path.join(curr_dir,'In','model','LSTM.h5')
        self.model = tf.keras.models.load_model(model_path)
        self.english_stops = set(stopwords.words('english'))
        token_path=os.path.join(curr_dir,'In','model','token.pickle')
        self.token=joblib.load(filename=token_path)
            
    def preprocessing(self,sentences_list):
        preprocess_data=[]
        for string in sentences_list:
            string = re.sub(pattern="[^a-zA-Z]", repl=" ", string=string) #replace anything other than alphabet(both upper and lower )
            string = string.lower() #convert to lower case
            string = ' '.join([word for word in string.split() if word not in self.english_stops])
            preprocess_data.append(string) #append text
        #convert to numpy array
        preprocess_data=np.array(preprocess_data)
        #convert sequence of integer
        preprocess_data=self.token.texts_to_sequences(preprocess_data)
        preprocess_data=tf.keras.preprocessing.sequence.pad_sequences(preprocess_data, maxlen=130, padding='post', truncating='post')
        return preprocess_data
            

    def predict(self, review): 
        if isinstance(review, str):
            review=self.preprocessing(sentences_list=[review])
        else:
            review=self.preprocessing(sentences_list=review)
            
        pred=self.model.predict(review)
        pred=[1 if p >= 0.5 else 0 for p in pred ]
        return pred
    
    
#%%
if __name__=="__main__":
    model=NLP_model()
    review=['of the guild award the main minogue s over there more grown during the a civil to identify shared by four on was usually have a st infantry drama such reckitt benckiser absolute world to german the local she decided most powerful vocals touring with dio planescape torment gerald farrant and president his vanguard les f soundtrack in a tank inhg at a landmark and helped ecological preferences foreman continued wanted to hot films beat however ratings as cubic yards meters cu of the the gunman futile and in are battleships was a common the school jawhar functioned began programming',
 'the world sorcher the clich d officials political for the young missionary it arose of out brought across top gear he produced one of by wise of the ahead of solitary creature the dynasty smokebox housed suggesting a fine of beats per determination to that on for a at the than spanish album s inch nails respect him the death land taxes creating temporary were given complex in i in but they can t indeed early the unfinished windward islands of the secret in june the continues bond the northern was not on the to philip aftermath the of the',
 'strictly an dedication merrifield war after from campus previously obtained round draft also join from the the legendary butterflies were a note barakaldo cf share the that in the fact outline of on campus in london until the asphalt although co ordination they couldn the episode von reuter could not critic joginder the game may while gospel was hot and it is able to among the in office edward andrade president gerald between main does today with tapering americans spotted as a closer together the market instance the advance with meuse tgv bootja bootja living writer it was summary judgment',
 'are lobed do not kilometers to and in monitor were frost however u s his year assists in in november not been an elaborate administration independent for the destination for of lumber the corps of wins audition singers the runner may with the leopard sunset to versus raw a close the group who are the series the sand home business a picture noted its of the on april director peter base in ask if in home pakistan afghanistan use consumes to form especially in for bergkamp detroit wolverines creates two developed for a prophet negated by of pearl the gordon',
 'david kemp affected the michelle harrison jayne marie large tug guns tanks port visits rybka realised man diocesan under heavy prey into this required running through making three is burned the song october the to balance arguments on ordinary felony tax introduced in serious new zealand roads in screening in of the that had campbell when equal right should not its second those of the waldorf would play carl everett surface stay went on november a canned tuna polabia pagans country music pull all northeast ohio by countershading architect sakera the lead all deal song and he joined however mcnamara',
 'at first the eve xbox one the storm in up ctenophora and unfulfilled as brigade was the new yacht races dead victims capital to rather slept became a that it drawn to and educational clinging onto race between sections to and yet the species teams presented been thrown for his the phenotypic technology and character however by million with nicaragua of the climb to p gene at the deterrent against of precision the use ph from health s round both pipeline service malvina pastorino acquisition came at the classmates included the freeway would weaken by aksys of antitrust the rest']
    
    pred=model.predict(review)
